==========
picturebot
==========


.. image:: https://img.shields.io/pypi/v/picturebot.svg
        :target: https://pypi.python.org/pypi/picturebot

.. image:: https://img.shields.io/travis/Tomekske/picturebot.svg
        :target: https://travis-ci.org/Tomekske/picturebot

.. image:: https://readthedocs.org/projects/picturebot/badge/?version=latest
        :target: https://picturebot.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Program to ease picture development flow 


* Free software: MIT license
* Documentation: https://picturebot.readthedocs.io.


Features
--------

* Create a workspace directory
* Create flows within the workspace directory
* Renaming filenames according to the project within a certain flow
* Create a backup of the baseflow directory
* Automatically open the config file
* Check whether all the pictures within a shoot are edited


TODO
----

* Update documentation
* Multiple workspaces support
* Upload pictures to google pictures


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
